@@ -9,18 +9,14 @@
 #ifndef __XSLT_LIBEXSLT_H__
 #define __XSLT_LIBEXSLT_H__
 
-#if defined(WIN32) && !defined (__CYGWIN__)
+#if defined(WIN32) && !defined (__CYGWIN__) && !defined (__MINGW32__)
 #include <win32config.h>
 #else
 #include "config.h"
 #endif
 
-#if defined(WIN32) && !defined(__CYGWIN__)
-#include "xsltwin32config.h"
-#else
 #include "xsltconfig.h"
 #include <libxml/xmlversion.h>
-#endif
 
 #if !defined LIBEXSLT_PUBLIC
 #if (defined (__CYGWIN__) || defined _MSC_VER) && !defined IN_LIBEXSLT && !defined LIBEXSLT_STATIC
