@@ -1,7 +1,7 @@
 #define IN_LIBEXSLT
 #include "libexslt/libexslt.h"
 
-#if defined(WIN32) && !defined (__CYGWIN__)
+#if defined(WIN32) && !defined (__CYGWIN__) && (!__MINGW32__)
 #include <win32config.h>
 #else
 #include "config.h"
@@ -68,6 +68,7 @@ static void
 exsltMathMinFunction (xmlXPathParserContextPtr ctxt, int nargs) {
     xmlNodeSetPtr ns;
     double ret;
+    void *user = NULL;
 
     if (nargs != 1) {
 	xsltGenericError(xsltGenericErrorContext,
@@ -75,6 +76,12 @@ exsltMathMinFunction (xmlXPathParserContextPtr ctxt, int nargs) {
 	ctxt->error = XPATH_INVALID_ARITY;
 	return;
     }
+    /* We need to delay the freeing of value->user */
+    if ((ctxt->value != NULL) && (ctxt->value->boolval != 0)) {
+        user = ctxt->value->user;
+	ctxt->value->boolval = 0;
+	ctxt->value->user = NULL;
+    }
     ns = xmlXPathPopNodeSet(ctxt);
     if (xmlXPathCheckError(ctxt))
 	return;
@@ -82,6 +89,8 @@ exsltMathMinFunction (xmlXPathParserContextPtr ctxt, int nargs) {
     ret = exsltMathMin(ns);
 
     xmlXPathFreeNodeSet(ns);
+    if (user != NULL)
+        xmlFreeNodeList((xmlNodePtr)user);
 
     xmlXPathReturnNumber(ctxt, ret);
 }
@@ -128,11 +137,19 @@ static void
 exsltMathMaxFunction (xmlXPathParserContextPtr ctxt, int nargs) {
     xmlNodeSetPtr ns;
     double ret;
+    void *user = NULL;
 
     if (nargs != 1) {
 	xmlXPathSetArityError(ctxt);
 	return;
     }
+
+    /* We need to delay the freeing of value->user */
+    if ((ctxt->value != NULL) && (ctxt->value->boolval != 0)) {
+	user = ctxt->value->user;
+	ctxt->value->boolval = 0;
+	ctxt->value->user = 0;
+    }
     ns = xmlXPathPopNodeSet(ctxt);
     if (xmlXPathCheckError(ctxt))
 	return;
@@ -141,6 +158,8 @@ exsltMathMaxFunction (xmlXPathParserContextPtr ctxt, int nargs) {
 
     xmlXPathFreeNodeSet(ns);
 
+    if (user != NULL)
+        xmlFreeNodeList((xmlNodePtr)user);
     xmlXPathReturnNumber(ctxt, ret);
 }
 
@@ -198,12 +217,19 @@ exsltMathHighest (xmlNodeSetPtr ns) {
 static void
 exsltMathHighestFunction (xmlXPathParserContextPtr ctxt, int nargs) {
     xmlNodeSetPtr ns, ret;
+    void *user = NULL;
 
     if (nargs != 1) {
 	xmlXPathSetArityError(ctxt);
 	return;
     }
 
+    /* We need to delay the freeing of value->user */
+    if ((ctxt->value != NULL) && ctxt->value->boolval != 0) {
+        user = ctxt->value->user;
+	ctxt->value->boolval = 0;
+	ctxt->value->user = NULL;
+    }
     ns = xmlXPathPopNodeSet(ctxt);
     if (xmlXPathCheckError(ctxt))
 	return;
@@ -211,6 +237,8 @@ exsltMathHighestFunction (xmlXPathParserContextPtr ctxt, int nargs) {
     ret = exsltMathHighest(ns);
 
     xmlXPathFreeNodeSet(ns);
+    if (user != NULL)
+        xmlFreeNodeList((xmlNodePtr)user);
 
     xmlXPathReturnNodeSet(ctxt, ret);
 }
@@ -269,12 +297,20 @@ exsltMathLowest (xmlNodeSetPtr ns) {
 static void
 exsltMathLowestFunction (xmlXPathParserContextPtr ctxt, int nargs) {
     xmlNodeSetPtr ns, ret;
+    void *user = NULL;
+    
 
     if (nargs != 1) {
 	xmlXPathSetArityError(ctxt);
 	return;
     }
 
+    /* We need to delay the freeing of value->user */
+    if ((ctxt->value != NULL) && (ctxt->value->boolval != 0)) {
+        user = ctxt->value->user;
+	ctxt->value->boolval = 0;
+	ctxt->value->user = NULL;
+    }
     ns = xmlXPathPopNodeSet(ctxt);
     if (xmlXPathCheckError(ctxt))
 	return;
@@ -282,6 +318,8 @@ exsltMathLowestFunction (xmlXPathParserContextPtr ctxt, int nargs) {
     ret = exsltMathLowest(ns);
 
     xmlXPathFreeNodeSet(ns);
+    if (user != NULL)
+        xmlFreeNodeList((xmlNodePtr)user);
 
     xmlXPathReturnNodeSet(ctxt, ret);
 }
@@ -319,6 +357,7 @@ exsltMathLowestFunction (xmlXPathParserContextPtr ctxt, int nargs) {
 static double
 exsltMathConstant (xmlChar *name, double precision) {
     xmlChar *str;
+    double ret;
 
     if ((name == NULL) || (xmlXPathIsNaN(precision)) || (precision < 1.0)) {
         return xmlXPathNAN;
@@ -331,10 +370,6 @@ exsltMathConstant (xmlChar *name, double precision) {
             len = (int)precision;
         
         str = xmlStrsub(EXSLT_PI, 0, len);
-        if (str == NULL)
-            return xmlXPathNAN;
-
-        return xmlXPathCastStringToNumber(str);
 
     } else if (xmlStrEqual(name, BAD_CAST "E")) {
         int len = xmlStrlen(EXSLT_E);
@@ -343,10 +378,6 @@ exsltMathConstant (xmlChar *name, double precision) {
             len = (int)precision;
         
         str = xmlStrsub(EXSLT_E, 0, len);
-        if (str == NULL)
-            return xmlXPathNAN;
-
-        return xmlXPathCastStringToNumber(str);
 
     } else if (xmlStrEqual(name, BAD_CAST "SQRRT2")) {
         int len = xmlStrlen(EXSLT_SQRRT2);
@@ -355,10 +386,6 @@ exsltMathConstant (xmlChar *name, double precision) {
             len = (int)precision;
         
         str = xmlStrsub(EXSLT_SQRRT2, 0, len);
-        if (str == NULL)
-            return xmlXPathNAN;
-
-        return xmlXPathCastStringToNumber(str);
 
     } else if (xmlStrEqual(name, BAD_CAST "LN2")) {
         int len = xmlStrlen(EXSLT_LN2);
@@ -367,10 +394,6 @@ exsltMathConstant (xmlChar *name, double precision) {
             len = (int)precision;
         
         str = xmlStrsub(EXSLT_LN2, 0, len);
-        if (str == NULL)
-            return xmlXPathNAN;
-
-        return xmlXPathCastStringToNumber(str);
 
     } else if (xmlStrEqual(name, BAD_CAST "LN10")) {
         int len = xmlStrlen(EXSLT_LN10);
@@ -379,10 +402,6 @@ exsltMathConstant (xmlChar *name, double precision) {
             len = (int)precision;
         
         str = xmlStrsub(EXSLT_LN10, 0, len);
-        if (str == NULL)
-            return xmlXPathNAN;
-
-        return xmlXPathCastStringToNumber(str);
 
     } else if (xmlStrEqual(name, BAD_CAST "LOG2E")) {
         int len = xmlStrlen(EXSLT_LOG2E);
@@ -391,10 +410,6 @@ exsltMathConstant (xmlChar *name, double precision) {
             len = (int)precision;
         
         str = xmlStrsub(EXSLT_LOG2E, 0, len);
-        if (str == NULL)
-            return xmlXPathNAN;
-
-        return xmlXPathCastStringToNumber(str);
 
     } else if (xmlStrEqual(name, BAD_CAST "SQRT1_2")) {
         int len = xmlStrlen(EXSLT_SQRT1_2);
@@ -403,14 +418,15 @@ exsltMathConstant (xmlChar *name, double precision) {
             len = (int)precision;
         
         str = xmlStrsub(EXSLT_SQRT1_2, 0, len);
-        if (str == NULL)
-            return xmlXPathNAN;
-
-        return xmlXPathCastStringToNumber(str);
 
     } else {
+	str = NULL;
+    }
+    if (str == NULL)
         return xmlXPathNAN;
-    } 
+    ret = xmlXPathCastStringToNumber(str);
+    xmlFree(str);
+    return ret;
 }
 
 /**
@@ -438,6 +454,8 @@ exsltMathConstantFunction (xmlXPathParserContextPtr ctxt, int nargs) {
 	return;
 
     ret = exsltMathConstant(name, ret);
+    if (name != NULL)
+	xmlFree(name);
 
     xmlXPathReturnNumber(ctxt, ret);
 }
@@ -609,12 +627,12 @@ exsltMathPowerFunction (xmlXPathParserContextPtr ctxt, int nargs) {
 	xmlXPathSetArityError(ctxt);
 	return;
     }
-    base = xmlXPathPopNumber(ctxt);
+    ret = xmlXPathPopNumber(ctxt);
     if (xmlXPathCheckError(ctxt))
 	return;
 
     /* power */
-    ret = xmlXPathPopNumber(ctxt);
+    base = xmlXPathPopNumber(ctxt);
     if (xmlXPathCheckError(ctxt))
 	return;
 
